//
//  GPUImagePlayView.h
//  博坦创新
//
//  Created by Xu pan on 2019/6/27.
//  Copyright © 2019 Xu pan. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <AVFoundation/AVFoundation.h>

NS_ASSUME_NONNULL_BEGIN

typedef enum {
    FillModeStretch,                       // Stretch to fill the full view, which may distort the image outside of its normal aspect ratio
    FillModePreserveAspectRatio,           // Maintains the aspect ratio of the source image, adding bars of the specified background color
    FillModePreserveAspectRatioAndFill,    // Maintains the aspect ratio of the source image, zooming in on its center to fill the view
} FillMode;

@interface GPUImagePlayView : UIView

/// 设置VR模式
@property   (nonatomic,assign)      BOOL                VREnable;

/// 伸缩scale
@property   (nonatomic,assign)      CGFloat             scaleLevel;

/// DefaultMode: FillModePreserveAspectRatio
@property   (nonatomic,assign)          FillMode                            fillMode;

/// 设置数据流
/// @param pixelBuffer 数据buffer
- (BOOL)processCVPixelBuffer:(CVPixelBufferRef)pixelBuffer;

/// 设置数据流
/// @param pixelBuffer 数据buffer
/// @param frameTime frameTime 时间戳
- (BOOL)processCVPixelBuffer:(CVPixelBufferRef)pixelBuffer
                   frameTime:(CMTime)frameTime;

/// 设置image流
/// @param image 播放的image
/// @param frameTime 时间戳
- (BOOL)processImage:(UIImage *)image
           frameTime:(CMTime)frameTime;

/// 设置image二进制流
/// @param data buffdata
/// @param w width
/// @param h height
/// @param len length
/// @param frameTime 时间戳
- (BOOL)processImageData:(char *)data
                   width:(int)w
                  height:(int)h
                     len:(int)len
               frameTime:(CMTime)frameTime;

/// 设置播放模式
- (void)setPlayViewInputType;

@end

NS_ASSUME_NONNULL_END
