//
//  StreamControlManager.h
//  Version: 1.0
//
//  该文件用于拿视频流,手势识别处理以及解码的数据回调
//
//  Created by Xu pan on 2020/8/3.
//  Copyright © 2020 Xu pan. All rights reserved.

#import <Foundation/Foundation.h>
#import <CoreMedia/CoreMedia.h>
#import <UIKit/UIKit.h>

@protocol StreamControlManagerDelegate <NSObject>


@optional
/// 回调解码的CVPixelBufferRef数据
/// @param pixelBuf pBuf
/// @param frameTime pts
/// @param frameWidth 长
/// @param frameHeight 高
-(void)processCVPixelBuffer:(CVPixelBufferRef _Nullable )pixelBuf
                  frameTime:(CMTime)frameTime
                 frameWidth:(int)frameWidth
                frameHeight:(int)frameHeight;

@optional
/// 回调解码的图像数据
/// @param image 图像
/// @param frameTime pts
/// @param frameWidth 长
/// @param frameHeight 高
-(void)processImage:(UIImage *)image
          frameTime:(CMTime)frameTime
         frameWidth:(int)frameWidth
        frameHeight:(int)frameHeight;

@end

typedef bool(^gestureRecognitionBlock)(char * _Nullable pBuf, int bufW, int bufH, float bufLen);

@interface StreamControlManager : NSObject

/// 是否正在接收视频流（可用于判断是否正在播放）
@property   (nonatomic,assign,readonly)     BOOL                                        isReceiving;
@property   (nonatomic,assign)              id<StreamControlManagerDelegate> _Nullable            delegate;
//是否正在写录像
@property   (nonatomic,assign,readonly)     BOOL                                        isWritingMovie;

/// 开始接收视频流
-(void)startReceiveStreamcComplete:(void(^_Nullable)(void))complete;

/// 停止接收视频流
-(void)stopReceiveStreamComplete:(void(^_Nullable)(void))complete;

/// 流里拿图片
/// @param complete 完成回调
-(void)asyncGtePhotoFromStream:(void(^_Nullable)(BOOL isRec,UIImage * _Nullable image))complete;

/*
 functionTool这中的录像方法为次两方法
 **/

/// 流中取buff写影片
/// @param isSaveLocal 是否保存本地
/// @param isSaveTFCard 是否保存tf卡
/// @param filePath 本地保存你路径
/// @param frameRate 帧率
/// @param frameSize 尺寸
/// @param audioEnable 是否录音
/// @param complete 准备完成回调
-(void)starWriteMovieIsSaveLocal:(BOOL)isSaveLocal
                    isSaveTFcard:(BOOL)isSaveTFCard
                      ToFilePath:(NSString *_Nullable)filePath
                      frameRate:(int)frameRate
                      frameSize:(CGSize)frameSize
                    audioEnable:(BOOL)audioEnable
                        complete:(void(^_Nullable)(void))complete;

/// 结束写影片
/// @param complete 完成回调，返回写入的路径
-(void)stopWriteMovieComplete:(nonnull void (^)(NSString * _Nullable moviePath))complete;


-(void)startGestureRecognitionAction:(gestureRecognitionBlock _Nullable )bufConfig
                 recognitionInterval:(int)interval;
-(void)stopGestureRecognitionAction;
@end

