//
//  VisonFunctionTool.h
//  DeepSeaDemo
//
//  Created by Xu pan on 2021/1/11.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "StreamControlManager.h"
#import "GPUImagePlayView.h"

@class FTPFile;


@interface VisonFunctionTool : NSObject

/// 初始化纬盛wifi板，并建立连接(在连接纬盛wifi下)
+(void)initializeVisonWifiDevice;

/// 切断wifi连接
+(void)cutoffConnectWithWifiDevice;

//重连wifi连接
+(void)reconnectOfWifiDevice;

/// 是否连接上纬盛wifi设备
+(BOOL)isConnectedVisonWifiDevice;

/// 获取wifi信号强度
+(int)getWifiSignalQuality;

/// WIFIi型号
+(NSString *_Nullable)getWifiDeviceModel;

/// WiFi版本号
+(NSString *_Nullable)getWifiDeviceVersion;

/// 发送UDP指令
/// @param command 指令data
/// @param tag 指令标记
+(BOOL)sendUdpCommand:(NSData *_Nullable)command
                  tag:(int)tag;

/// 发送TCP指令
/// @param command 指令
/// @param tag 指令标记
+(void)sendTcpCommand:(NSData *_Nullable)command
                  tag:(int)tag;

/// 开始接收视频流
/// @param streamManager 流管理对象
/// @param complete 完成回调
+(void)startReceiveStreamFromStreamManager:(StreamControlManager *_Nullable)streamManager
                                  complete:(void(^_Nullable)(void))complete;

/// 停止接收视频流
/// @param streamManager 流管理对象
/// @param complete 完成回调
+(void)stopReceiveStreamFromStreamManager:(StreamControlManager *_Nullable)streamManager
                                 complete:(void(^_Nullable)(void))complete;

/// 拍照动作(视频流中截图和板端取原图)
/// @param streamManager 流管理对象
/// @param need 是否需要板端回传原图
/// @param complete 完成回调
+(void)asyncTakePhotoFromStream:(StreamControlManager *_Nullable)streamManager
                needSourceImage:(BOOL)need
                       complete:(void(^_Nullable)(UIImage * _Nullable streamImage,UIImage * _Nullable sourceImage))complete;

/// 开始写录像文件动作
/// @param isSaveLocal 是否保存本地
/// @param isSaveTFCard 是否保存tf卡
/// @param streamManager 流管理对象
/// @param filePath 写入路径
/// @param frameRate 帧率
/// @param frameSize 尺寸
/// @param audioEnable 是否录制声音
/// @param complete 准备完成回调
+(void)starWriteMovieIsSaveLocal:(BOOL)isSaveLocal
                    isSaveTFcard:(BOOL)isSaveTFCard
                      FromStream:(StreamControlManager *_Nullable)streamManager
                      ToFilePath:(NSString *_Nullable)filePath
                       frameRate:(int)frameRate
                       frameSize:(CGSize)frameSize
                     audioEnable:(BOOL)audioEnable
                        complete:(void(^_Nullable)(void))complete;


/// 停止影片写入
/// @param complete 完成回调，返回写入的地址
+(void)stopWriteMovieFromStream:(StreamControlManager *_Nullable)streamManager
                       Complete:(nonnull void (^)(NSString * _Nullable moviePath))complete;


/// VR model
/// @param playView 图显View
/// @param enable enable
+(void)setPlayView:(GPUImagePlayView *_Nullable)playView
          VREnable:(BOOL)enable;

/// 镜头画面翻转
+(void)imageFileAction;

/// 镜头切换动作
/// @param streamManager 流管理对象
+(void)switchLensActionFromStream:(StreamControlManager *_Nullable)streamManager;

/// 设置画面缩放等级
/// @param playView 播放视图
/// @param level 缩放等级（1为正常）
+(void)setPlayView:(GPUImagePlayView *_Nullable)playView scaleLevel:(float)level;

/// 重命名wifi名
/// @param ssid wifi名
+(void)reNameSSID:(NSString *_Nullable)ssid;
 
@end
